'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var fontSizes = [12, 15, 17, 20, 24, 28, 34, 42, 50, 70];
var fonts = {
  headlineSerif: "GH Guardian Headline, Georgia, serif",
  bodySerif: "GuardianTextEgyptian, Georgia, serif",
  bodySans: "GuardianTextSans, Helvetica Neue, Helvetica, Arial, Lucida Grande, sans-serif"
};
var lineHeights = ["1.15em", "1.35em", "1.45em"];
var fontWeights = [300, 400, 500, 700]; // Arrays of colours should have pillar colors first
// e.g. for sport:
// const [dark, main, bright, pastel, faded] = colors.blue

var colors = {
  reds: ["#ab0613", //news-dark
  "#c70000", //news-main
  "#ff4e36", //news-bright
  "#ffbac8", //news-pastel
  "#fff4f2"],
  oranges: ["#AB0613", //opinion-dark
  "#E05E00", //opinion-main
  "#FF7F0F", //opinion-bright
  "#F9B376", //opinion-pastel
  "#FEF9F5"],
  blues: ["#005689", //sport-dark
  "#0084C6", //sport-main
  "#00B2FF", //sport-bright
  "#90DCFF", //sport-pastel
  "#F1F8FC", //sport-faded
  "#041F4A", //brand-dark
  "#052962", //brand-main
  "#0077B3", //brand-bright
  "#506991", //brand-pastel
  "#B6C5DB"],
  browns: ["#6B5840", //culture-dark
  "#A1845C", //culture-main
  "#EACCA0", //culture-bright
  "#E7D4B9", //culture-pastel
  "#FBF6EF"],
  pinks: ["#7D0068", //lifestyle-dark
  "#BB3B80", //lifestyle-main
  "#FFABDB", //lifestyle-bright
  "#FEC8D3", //lifestyle-pastel
  "#FEEEF7"],
  yellows: ["#F3C100", //highlight-dark
  "#FFE500"],
  greens: ["#185E36", "#22874D", "#65A897", //labs-dark
  "#69D1CA"],
  grays: ["#121212", //neutral-7
  "#1a1a1a", //neutral-10
  "#333333", //neutral-20
  "#767676", //neutral-46
  "#999999", //neutral-60
  "#d9d9d9", //neutral-85
  "#dcdcdc", //neutral-86
  "#ededed", //neutral-93
  "#f6f6f6", //neutral-97
  "#ffffff", //neutral-100
  "#3F464A"]
};
var space = [3, 6, 12, 18, 24, 36, 48, 96];
var size = [24, 36, 44];
var breakpoints = [740, 980, 1140, 1300]; // Diverges from https://system-ui.com
// At these widths, there are tweaks to the
// fluid grid on mobile devices

var tweakpoints = [375, 480, 660];
var transitions = [".2s cubic-bezier(.64, .57, .67, 1.53)", ".3s ease-in-out", ".65s ease-in-out"];

var transitions$1 = {
  "short": transitions[0],
  medium: transitions[1],
  "long": transitions[2]
};

var visuallyHidden = "\n\tposition: absolute;\n\topacity: 0;\n\theight: 0;\n\twidth: 0;\n\ttop: 0;\n\tleft: 0;\n";
var focusHalo = "\n\toutline: 0;\n\tbox-shadow: 0 0 0 5px #00B2FF;\n\tz-index: 9;\n";

var breakpointMap = {
  mobileMedium: tweakpoints[0],
  mobileLandscape: tweakpoints[1],
  phablet: tweakpoints[2],
  tablet: breakpoints[0],
  desktop: breakpoints[1],
  leftCol: breakpoints[2],
  wide: breakpoints[3]
};

var minWidth = function minWidth(from) {
  return "@media (min-width: ".concat("".concat(from, "px"), ")");
};

var maxWidth = function maxWidth(until) {
  return "@media (max-width: ".concat("".concat(until - 1, "px"), ")");
};

var minWidthMaxWidth = function minWidthMaxWidth(from, until) {
  return "@media (min-width: ".concat("".concat(from, "px"), ") and (max-width: ", "".concat(until - 1, "px"), ")");
}; // e.g. until.*


var until = {
  mobileMedium: maxWidth(breakpointMap.mobileMedium),
  mobileLandscape: maxWidth(breakpointMap.mobileLandscape),
  phablet: maxWidth(breakpointMap.phablet),
  tablet: maxWidth(breakpointMap.tablet),
  desktop: maxWidth(breakpointMap.desktop),
  leftCol: maxWidth(breakpointMap.leftCol),
  wide: maxWidth(breakpointMap.wide) // e.g. from.*.until.*

};
var from = {
  mobileMedium: {
    until: {
      mobileLandscape: minWidthMaxWidth(breakpointMap.mobileMedium, breakpointMap.mobileLandscape),
      phablet: minWidthMaxWidth(breakpointMap.mobileMedium, breakpointMap.phablet),
      tablet: minWidthMaxWidth(breakpointMap.mobileMedium, breakpointMap.tablet),
      desktop: minWidthMaxWidth(breakpointMap.mobileMedium, breakpointMap.desktop),
      leftCol: minWidthMaxWidth(breakpointMap.mobileMedium, breakpointMap.leftCol),
      wide: minWidthMaxWidth(breakpointMap.mobileMedium, breakpointMap.wide)
    }
  },
  mobileLandscape: {
    until: {
      phablet: minWidthMaxWidth(breakpointMap.mobileLandscape, breakpointMap.phablet),
      tablet: minWidthMaxWidth(breakpointMap.mobileLandscape, breakpointMap.tablet),
      desktop: minWidthMaxWidth(breakpointMap.mobileLandscape, breakpointMap.desktop),
      leftCol: minWidthMaxWidth(breakpointMap.mobileLandscape, breakpointMap.leftCol),
      wide: minWidthMaxWidth(breakpointMap.mobileLandscape, breakpointMap.wide)
    }
  },
  phablet: {
    until: {
      tablet: minWidthMaxWidth(breakpointMap.phablet, breakpointMap.tablet),
      desktop: minWidthMaxWidth(breakpointMap.phablet, breakpointMap.desktop),
      leftCol: minWidthMaxWidth(breakpointMap.phablet, breakpointMap.leftCol),
      wide: minWidthMaxWidth(breakpointMap.phablet, breakpointMap.wide)
    }
  },
  tablet: {
    until: {
      desktop: minWidthMaxWidth(breakpointMap.tablet, breakpointMap.desktop),
      leftCol: minWidthMaxWidth(breakpointMap.tablet, breakpointMap.leftCol),
      wide: minWidthMaxWidth(breakpointMap.tablet, breakpointMap.wide)
    }
  },
  desktop: {
    until: {
      leftCol: minWidthMaxWidth(breakpointMap.desktop, breakpointMap.leftCol),
      wide: minWidthMaxWidth(breakpointMap.desktop, breakpointMap.wide)
    }
  },
  leftCol: {
    until: {
      wide: minWidthMaxWidth(breakpointMap.leftCol, breakpointMap.wide)
    }
  } // min-widths

};
var mobileMedium = minWidth(breakpointMap.mobileMedium);
var mobileLandscape = minWidth(breakpointMap.mobileLandscape);
var phablet = minWidth(breakpointMap.phablet);
var tablet = minWidth(breakpointMap.tablet);
var desktop = minWidth(breakpointMap.desktop);
var leftCol = minWidth(breakpointMap.leftCol);
var wide = minWidth(breakpointMap.wide);

var palette = {
  brand: {
    dark: colors.blues[5],
    main: colors.blues[6],
    bright: colors.blues[7],
    pastel: colors.blues[8],
    faded: colors.blues[9]
  },
  yellow: {
    dark: colors.yellows[0],
    main: colors.yellows[1]
  },
  neutral: {
    7: colors.grays[0],
    10: colors.grays[1],
    20: colors.grays[2],
    46: colors.grays[3],
    60: colors.grays[4],
    85: colors.grays[5],
    86: colors.grays[6],
    93: colors.grays[7],
    97: colors.grays[8],
    100: colors.grays[9],
    specialReport: colors.grays[10]
  },
  error: {
    main: colors.reds[1]
  },
  news: {
    dark: colors.reds[0],
    main: colors.reds[1],
    bright: colors.reds[2],
    pastel: colors.reds[3],
    faded: colors.reds[4]
  },
  opinion: {
    dark: colors.oranges[0],
    main: colors.oranges[1],
    bright: colors.oranges[2],
    pastel: colors.oranges[3],
    faded: colors.oranges[4]
  },
  sport: {
    dark: colors.blues[0],
    main: colors.blues[1],
    bright: colors.blues[2],
    pastel: colors.blues[3],
    faded: colors.blues[4]
  },
  culture: {
    dark: colors.browns[0],
    main: colors.browns[1],
    bright: colors.browns[2],
    pastel: colors.browns[3],
    faded: colors.browns[4]
  },
  lifestyle: {
    dark: colors.pinks[0],
    main: colors.pinks[1],
    bright: colors.pinks[2],
    pastel: colors.pinks[3],
    faded: colors.pinks[4]
  },
  labs: {
    dark: colors.greens[2],
    main: colors.greens[3]
  }
};

var size$1 = {
  small: size[0],
  medium: size[1],
  large: size[2]
};

var space$1 = {
  half: space[0],
  1: space[1],
  2: space[2],
  3: space[3],
  4: space[4],
  6: space[5],
  8: space[6],
  16: space[7]
};

var headlineSizes = {
  1: fontSizes[2],
  2: fontSizes[3],
  3: fontSizes[4],
  4: fontSizes[5],
  5: fontSizes[6],
  6: fontSizes[7],
  7: fontSizes[8],
  8: fontSizes[9]
};
var bodySizes = {
  1: fontSizes[1],
  2: fontSizes[2]
};
var textSansSizes = {
  1: fontSizes[0],
  2: fontSizes[1],
  3: fontSizes[2],
  4: fontSizes[3],
  5: fontSizes[4],
  6: fontSizes[5],
  7: fontSizes[6],
  8: fontSizes[7],
  9: fontSizes[8],
  10: fontSizes[9]
};
var fontSizeMapping = {
  headline: headlineSizes,
  body: bodySizes,
  textSans: textSansSizes
};
var fontMapping = {
  headline: fonts.headlineSerif,
  body: fonts.bodySerif,
  textSans: fonts.bodySans
};
var lineHeightMapping = {
  tight: lineHeights[0],
  regular: lineHeights[1],
  loose: lineHeights[2]
};
var fontWeightMapping = {
  headline: {
    light: {
      fontWeight: fontWeights[0],
      hasItalic: true
    },
    medium: {
      fontWeight: fontWeights[2],
      hasItalic: true
    },
    bold: {
      fontWeight: fontWeights[3],
      hasItalic: false
    }
  },
  body: {
    regular: {
      fontWeight: fontWeights[1],
      hasItalic: true
    },
    bold: {
      fontWeight: fontWeights[3],
      hasItalic: true
    }
  },
  textSans: {
    regular: {
      fontWeight: fontWeights[1],
      hasItalic: true
    },
    bold: {
      fontWeight: fontWeights[3],
      hasItalic: false
    }
  }
};

var fs = function fs(_ref) {
  var category = _ref.category,
      level = _ref.level,
      lineHeight = _ref.lineHeight,
      fontWeight = _ref.fontWeight;
  var fontFamilyValue = fontMapping[category];
  var fontSizeValue = fontSizeMapping[category][level];
  var lineHeightValue = lineHeightMapping[lineHeight];
  var fontWeightDefinition = fontWeightMapping[category][fontWeight];
  return "\n\tfont-family: ".concat(fontFamilyValue, ";\n\tfont-size: ").concat(fontSizeValue, "px;\n\tline-height: ").concat(lineHeightValue, ";\n\t").concat(fontWeightDefinition ? "font-weight: ".concat(fontWeightDefinition.fontWeight) : "", ";\n\t");
};

var headline = function headline(_ref2) {
  var level = _ref2.level,
      _ref2$lineHeight = _ref2.lineHeight,
      lineHeight = _ref2$lineHeight === void 0 ? "tight" : _ref2$lineHeight,
      _ref2$fontWeight = _ref2.fontWeight,
      fontWeight = _ref2$fontWeight === void 0 ? "medium" : _ref2$fontWeight;
  return fs({
    category: "headline",
    level: level,
    lineHeight: lineHeight,
    fontWeight: fontWeight
  });
};

var body = function body(_ref3) {
  var level = _ref3.level,
      _ref3$lineHeight = _ref3.lineHeight,
      lineHeight = _ref3$lineHeight === void 0 ? "loose" : _ref3$lineHeight,
      _ref3$fontWeight = _ref3.fontWeight,
      fontWeight = _ref3$fontWeight === void 0 ? "regular" : _ref3$fontWeight;
  return fs({
    category: "body",
    level: level,
    lineHeight: lineHeight,
    fontWeight: fontWeight
  });
};

var textSans = function textSans(_ref4) {
  var level = _ref4.level,
      _ref4$lineHeight = _ref4.lineHeight,
      lineHeight = _ref4$lineHeight === void 0 ? "loose" : _ref4$lineHeight,
      _ref4$fontWeight = _ref4.fontWeight,
      fontWeight = _ref4$fontWeight === void 0 ? "regular" : _ref4$fontWeight;
  return fs({
    category: "textSans",
    level: level,
    lineHeight: lineHeight,
    fontWeight: fontWeight
  });
};

Object.freeze(headlineSizes);
Object.freeze(bodySizes);
Object.freeze(textSansSizes);

exports.body = body;
exports.bodySizes = bodySizes;
exports.breakpoints = breakpointMap;
exports.desktop = desktop;
exports.focusHalo = focusHalo;
exports.from = from;
exports.headline = headline;
exports.headlineSizes = headlineSizes;
exports.leftCol = leftCol;
exports.mobileLandscape = mobileLandscape;
exports.mobileMedium = mobileMedium;
exports.palette = palette;
exports.phablet = phablet;
exports.size = size$1;
exports.space = space$1;
exports.tablet = tablet;
exports.textSans = textSans;
exports.textSansSizes = textSansSizes;
exports.transitions = transitions$1;
exports.until = until;
exports.visuallyHidden = visuallyHidden;
exports.wide = wide;
